@@ -1,5 +1,5 @@
 /* opencdk.h - Open Crypto Development Kit (OpenCDK)
- *        Copyright (C) 2001, 2002, 2003 Timo Schulz
+ *        Copyright (C) 2001, 2002, 2003, 2005 Timo Schulz
  *
  * This file is part of OpenCDK.
  *
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with OpenCDK; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #ifndef OPENCDK_H
@@ -23,7 +23,7 @@
 
 #include <stdarg.h>
 
-#define OPENCDK_VERSION "0.5.2"
+#define OPENCDK_VERSION "0.5.7"
 
 #ifdef __cplusplus
 extern "C" {
@@ -266,7 +266,8 @@ enum cdk_key_flag_t {
     CDK_KEY_VALID   = 0,
     CDK_KEY_INVALID = 1, /* missing or wrong self signature */
     CDK_KEY_EXPIRED = 2,
-    CDK_KEY_REVOKED = 4
+    CDK_KEY_REVOKED = 4,
+    CDK_KEY_NOSIGNER= 8,
 };
 
 enum cdk_trust_flag_t {
@@ -353,7 +354,7 @@ typedef enum {
   )
 
 struct cdk_pkt_userid_s {
-    unsigned long len;
+    unsigned int len;
     unsigned is_primary:1;
     unsigned is_revoked:1;
     unsigned mdc_feature:1;
@@ -361,7 +362,7 @@ struct cdk_pkt_userid_s {
     unsigned char * attrib_img; /* Tag 17 if not null */
     size_t attrib_len;
     size_t prefs_size;
-    unsigned long created;
+    unsigned int created;
     char name[1];
 };
 typedef struct cdk_pkt_userid_s *cdk_pkt_userid_t;
@@ -370,10 +371,10 @@ struct cdk_pkt_pubkey_s {
     unsigned char version;
     unsigned char pubkey_algo;
     unsigned char fpr[20];
-    unsigned long keyid[2];
-    unsigned long main_keyid[2];
-    unsigned long timestamp;
-    unsigned long expiredate;
+    unsigned int keyid[2];
+    unsigned int main_keyid[2];
+    unsigned int timestamp;
+    unsigned int expiredate;
     cdk_mpi_t mpi[4];
     unsigned is_revoked:1;
     unsigned is_invalid:1;
@@ -388,11 +389,11 @@ typedef struct cdk_pkt_pubkey_s *cdk_pkt_pubkey_t;
 
 struct cdk_pkt_seckey_s {
     cdk_pkt_pubkey_t pk;
-    unsigned long expiredate;
+    unsigned int expiredate;
     int version;
     int pubkey_algo;
-    unsigned long keyid[2];
-    unsigned long main_keyid[2];
+    unsigned int keyid[2];
+    unsigned int main_keyid[2];
     unsigned char s2k_usage;
     struct {
         unsigned char algo;
@@ -415,9 +416,9 @@ typedef struct cdk_pkt_seckey_s *cdk_pkt_seckey_t;
 struct cdk_pkt_signature_s {
     unsigned char version;
     unsigned char sig_class;
-    unsigned long timestamp;
-    unsigned long expiredate;
-    unsigned long keyid[2];
+    unsigned int timestamp;
+    unsigned int expiredate;
+    unsigned int keyid[2];
     unsigned char pubkey_algo;
     unsigned char digest_algo;
     unsigned char digest_start[2];
@@ -437,13 +438,13 @@ struct cdk_pkt_signature_s {
         unsigned valid:1;
         unsigned missing_key:1;
     } flags;  
-    unsigned long key[2]; /* only valid for key signatures */
+    unsigned int key[2]; /* only valid for key signatures */
 };
 typedef struct cdk_pkt_signature_s *cdk_pkt_signature_t;
 
 struct cdk_pkt_onepass_sig_s {
     unsigned char version;
-    unsigned long keyid[2];
+    unsigned int keyid[2];
     unsigned char sig_class;
     unsigned char digest_algo;
     unsigned char pubkey_algo;
@@ -454,7 +455,7 @@ typedef struct cdk_pkt_onepass_sig_s * cdk_pkt_onepass_sig_t;
 
 struct cdk_pkt_pubkey_enc_s {
     unsigned char version;
-    unsigned long keyid[2];
+    unsigned int keyid[2];
     int throw_keyid;
     unsigned char pubkey_algo;
     cdk_mpi_t mpi[2];
@@ -473,7 +474,7 @@ typedef struct cdk_pkt_symkey_enc_s *cdk_pkt_symkey_enc_t;
 
 
 struct cdk_pkt_encrypted_s {
-    unsigned long len;
+    unsigned int len;
     int extralen;
     unsigned char mdc_method;
     cdk_stream_t buf;
@@ -488,10 +489,10 @@ typedef struct cdk_pkt_mdc_s *cdk_pkt_mdc_t;
 
 
 struct cdk_pkt_literal_s {
-    unsigned long len;
+    unsigned int len;
     cdk_stream_t buf;
     int mode;
-    unsigned long timestamp;
+    unsigned int timestamp;
     int namelen;
     char name[1];
 };
@@ -499,7 +500,7 @@ typedef struct cdk_pkt_literal_s *cdk_pkt_literal_t;
 
 
 struct cdk_pkt_compressed_s {
-    unsigned long len;
+    unsigned int len;
     int algorithm;
     cdk_stream_t buf;
 };
@@ -532,7 +533,7 @@ typedef struct cdk_packet_s *cdk_packet_t;
 /* memory routines */
 typedef void (*cdk_log_fnc_t) (void *, int, const char *, va_list);
 void cdk_set_log_level (int lvl);
-void cdk_set_log_handler (cdk_log_fnc_t logfnc, void * opaque);
+void cdk_set_log_handler (cdk_log_fnc_t logfnc, void * opaq);
 const char* cdk_strerror (int ec);
 void cdk_set_malloc_hooks (void *(*new_alloc_func) (size_t n),
                            void *(*new_alloc_secure_func) (size_t n),
@@ -619,13 +620,13 @@ int cdk_pk_get_nskey (int algo);
 int cdk_pk_get_nsig (int algo);
 int cdk_pk_get_nenc (int algo);
 int cdk_pk_get_fingerprint (cdk_pkt_pubkey_t pk, unsigned char * fpr);
-unsigned long cdk_pk_fingerprint_get_keyid (const unsigned char * fpr,
+unsigned int cdk_pk_fingerprint_get_keyid (const unsigned char * fpr,
                                             size_t fprlen,
-                                            unsigned long * keyid);
-unsigned long cdk_pk_get_keyid (cdk_pkt_pubkey_t pk, unsigned long * keyid);
-unsigned long cdk_sk_get_keyid (cdk_pkt_seckey_t sk, unsigned long * keyid);
-unsigned long cdk_sig_get_keyid (cdk_pkt_signature_t sig,
-                                 unsigned long * keyid);
+                                            unsigned int * keyid);
+unsigned int cdk_pk_get_keyid (cdk_pkt_pubkey_t pk, unsigned int * keyid);
+unsigned int cdk_sk_get_keyid (cdk_pkt_seckey_t sk, unsigned int * keyid);
+unsigned int cdk_sig_get_keyid (cdk_pkt_signature_t sig,
+                                 unsigned int * keyid);
 cdk_error_t cdk_sk_unprotect( cdk_pkt_seckey_t sk, const char * pw );
 cdk_error_t cdk_sk_protect( cdk_pkt_seckey_t sk, const char * pw );
 cdk_error_t cdk_pk_from_secret_key( cdk_pkt_seckey_t sk,
@@ -696,19 +697,19 @@ int cdk_stream_peek( cdk_stream_t inp, unsigned char *s, size_t count );
 cdk_error_t cdk_keydb_new( cdk_keydb_hd_t * r_hd, int type, void * data,
                            size_t count);
 cdk_error_t cdk_keydb_open( cdk_keydb_hd_t hd, cdk_stream_t * ret_kr );
-int cdk_keydb_check_sk( cdk_keydb_hd_t hd, unsigned long * keyid );
+int cdk_keydb_check_sk( cdk_keydb_hd_t hd, unsigned int * keyid );
 cdk_error_t cdk_keydb_search_start( cdk_keydb_hd_t hd, int type, void * desc );
 cdk_error_t cdk_keydb_search( cdk_keydb_hd_t hd, cdk_kbnode_t * ret_key );
 void cdk_keydb_free( cdk_keydb_hd_t hd );
-cdk_error_t cdk_keydb_get_bykeyid( cdk_keydb_hd_t hd, unsigned long * keyid,
+cdk_error_t cdk_keydb_get_bykeyid( cdk_keydb_hd_t hd, unsigned int * keyid,
                                    cdk_kbnode_t * ret_pk );
 cdk_error_t cdk_keydb_get_byfpr( cdk_keydb_hd_t hd, const unsigned char * fpr,
                                  cdk_kbnode_t * ret_pk );
 cdk_error_t cdk_keydb_get_bypattern( cdk_keydb_hd_t hd, const char * patt,
                                      cdk_kbnode_t * ret_pk );
-cdk_error_t cdk_keydb_get_pk( cdk_keydb_hd_t khd, unsigned long * keyid,
+cdk_error_t cdk_keydb_get_pk( cdk_keydb_hd_t khd, unsigned int * keyid,
                       cdk_pkt_pubkey_t* ret_pk );
-cdk_error_t cdk_keydb_get_sk( cdk_keydb_hd_t khd, unsigned long * keyid,
+cdk_error_t cdk_keydb_get_sk( cdk_keydb_hd_t khd, unsigned int * keyid,
                               cdk_pkt_seckey_t* ret_sk );
 cdk_error_t cdk_keydb_get_keyblock( cdk_stream_t inp, cdk_kbnode_t * ret_key );
 cdk_error_t cdk_keydb_idx_rebuild( cdk_keydb_hd_t hd );
